import React, { useContext } from 'react';
import { PrimaryTitle } from './components/PrimaryTitle';
import { SecondaryTitle } from './components/SecondaryTitle';
import { SharedPropContext } from './components/Context';
/**
 * Renders the title component for the AuraBeam.
 * The title is the main heading of the AuraBeam.
 *
 * @component
 * @param {AuraBeamTitleProps} props - The props for the AuraBeamTitle component.
 * @param {string} props.title - The title text.
 * @param {string} [props.type="primary"] - The type of the title (primary or secondary).
 * @param {Color} [props.color="white"] - The color of the title.
 * @param {string} [props.positioning="left"] - The positioning of the title (left or right).
 * @returns {JSX.Element} The rendered AuraBeamTitle component.
 */
export const AuraBeamTitle = ({ title, type = "primary", ...props }) => {
    const sharedProps = useContext(SharedPropContext);
    const right = props.positioning ? props.positioning === "right" : sharedProps.positioning === 'right';
    const primary = type === "primary";
    return (React.createElement("div", { className: "relative flex items-center gap-2" }, primary ?
        React.createElement(PrimaryTitle, { text: title, right: right, color: props.color || sharedProps.color })
        :
            React.createElement(SecondaryTitle, { text: title, right: right, color: props.color || sharedProps.color })));
};
//# sourceMappingURL=AuraBeamTitle.js.map